EspHttpClient

Struct EspHttpClient 

pub struct EspHttpClient {
    stack: Stack<'static>,
    tls_seed: u64,
}

Fields

stack: Stack<'static>tls_seed: u64

Implementations

Source

impl EspHttpClient

pub fn new(stack: Stack<'static>, tls_seed: u64) -> Self

Creates a new client from a network stack and TLS seed.

pub async fn request( &self, method: Method, url: &str, body: Option<&[u8]>, ) -> Result<Response, Error>

Sends an HTTP request to url, following up to 5 redirects automatically.

Errors

Returns [Error::Codec] if the redirect limit is exceeded or a redirect response is missing the Location header.