get_system_config

Function get_system_config 

async fn get_system_config() -> Result<Json<SystemConfiguration>, Error>
gets and returns the currently stored system config, create a new default config if none is present (first boot)