post_system_config

Function post_system_config 

async fn post_system_config(
    __arg0: JsonWithUnescapeBufferSize<SystemConfiguration, HTTP_BUFFER_SIZE>,
) -> Result<(), Error>
receives an updated system configuration from the frontend and saves it to NVS. The config is only saved if there are changes to avoid flash wear.