Widget

Struct Widget 

pub struct Widget {
    get_config_schema: Func,
    get_name: Func,
    get_run_update_cycle_seconds: Func,
    get_version: Func,
    run: Func,
}
Auto-generated bindings for an instance a component which implements the world widget.

This structure can be created through a number of means depending on your requirements and what you have on hand:

These methods are all equivalent to one another and move around the tradeoff of what work is performed when.

Fields

get_config_schema: Funcget_name: Funcget_run_update_cycle_seconds: Funcget_version: Funcrun: Func

Implementations

Source

impl Widget

pub fn instantiate<_T>( store: impl AsContextMut<Data = _T>, component: &Component, linker: &Linker<_T>, ) -> Result<Widget>

Convenience wrapper around WidgetPre::new and WidgetPre::instantiate.

pub fn new(store: impl AsContextMut, instance: &Instance) -> Result<Widget>

Convenience wrapper around WidgetIndices::new and WidgetIndices::load.

pub fn add_to_linker<T, D>( linker: &mut Linker<T>, host_getter: fn(&mut T) -> D::Data<'_>, ) -> Result<()>
where D: HostWithStore + HostWithStore + HostWithStore + HostWithStore + HostWithStore, for<'a> D::Data<'a>: Host + Host + Host + Host + Host, T: 'static,

pub fn call_get_name<S: AsContextMut>(&self, store: S) -> Result<String>

Return the name of the widget

pub fn call_get_version<S: AsContextMut>(&self, store: S) -> Result<String>

Return the semantic version of the widget

pub fn call_get_config_schema<S: AsContextMut>( &self, store: S, ) -> Result<String>

Return the config JSON schema string

pub fn call_get_run_update_cycle_seconds<S: AsContextMut>( &self, store: S, ) -> Result<u32>

Returns the run update cycle in seconds. With this, widgets can control how frequently they shall be updated.

pub fn call_run<S: AsContextMut>( &self, store: S, arg0: &WidgetContext, ) -> Result<WidgetResult>

Invoke the widget with the given context