WidgetIndices

Struct WidgetIndices 

pub struct WidgetIndices {
    get_config_schema: ComponentExportIndex,
    get_name: ComponentExportIndex,
    get_run_update_cycle_seconds: ComponentExportIndex,
    get_version: ComponentExportIndex,
    run: ComponentExportIndex,
}
Auto-generated bindings for index of the exports of widget.

This is an implementation detail of WidgetPre and can be constructed if needed as well.

For more information see Widget as well.

Fields

get_config_schema: ComponentExportIndexget_name: ComponentExportIndexget_run_update_cycle_seconds: ComponentExportIndexget_version: ComponentExportIndexrun: ComponentExportIndex

Implementations

Source

impl WidgetIndices

pub fn new<_T>(_instance_pre: &InstancePre<_T>) -> Result<Self>

Creates a new copy of WidgetIndices bindings which can then be used to instantiate into a particular store.

This method may fail if the component does not have the required exports.

pub fn load( &self, store: impl AsContextMut, instance: &Instance, ) -> Result<Widget>

Uses the indices stored in self to load an instance of Widget from the instance provided.

Note that at this time this method will additionally perform type-checks of all exports.