WidgetPre

Struct WidgetPre 

pub struct WidgetPre<T: 'static> {
    instance_pre: InstancePre<T>,
    indices: WidgetIndices,
}
Auto-generated bindings for a pre-instantiated version of a component which implements the world widget.

This structure is created through WidgetPre::new which takes a InstancePre that has been created through a Linker.

For more information see Widget as well.

Fields

instance_pre: InstancePre<T>indices: WidgetIndices

Implementations

Source

impl<_T: 'static> WidgetPre<_T>

pub fn new(instance_pre: InstancePre<_T>) -> Result<Self>

Creates a new copy of WidgetPre bindings which can then be used to instantiate into a particular store.

This method may fail if the component behind instance_pre does not have the required exports.

pub fn engine(&self) -> &Engine

pub fn instance_pre(&self) -> &InstancePre<_T>

pub fn instantiate(&self, store: impl AsContextMut<Data = _T>) -> Result<Widget>

Instantiates a new instance of Widget within the store provided.

This function will use self as the pre-instantiated instance to perform instantiation. Afterwards the preloaded indices in self are used to lookup all exports on the resulting instance.