pub struct EspTime {
fetch_time_offset: Option<Instant>,
fetched_time_epoch: Option<u64>,
}Fields
fetch_time_offset: Option<Instant>fetched_time_epoch: Option<u64>Implementations
Sourceimpl EspTime
impl EspTime
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new, EspTime. Call fetch_time before use.
Sourcepub async fn fetch_time(&mut self)
pub async fn fetch_time(&mut self)
Fetches the current Unix timestamp from timeapi.io
Also gets the current time since boot to be able to compute the current time based on the elapsed time since the fetch.
Panics
Panics if the HTTP request fails or the response cannot be parsed.