WidgetManager

Struct WidgetManager 

pub struct WidgetManager;
Zero-sized helper that provides static methods for widget lifecycle management.

Implementations

Source

impl WidgetManager

pub async fn install_widget( download_url: &str, description: &str, ) -> Result<(), WidgetManagerError>

Download and persist a widget Also adds a default configuration for the widget

Arguments
  • download_url - The URL to download the widget from
  • description - A description of the widget
Returns

An error if the download or persisting failed

pub async fn deinstall_widget( widget_name: &str, ) -> Result<(), WidgetManagerError>

Deinstall a widget

Arguments
  • widget_name - The name of the widget to deinstall
Returns

An error if the deinstallation failed

pub async fn get_widget( widget_name: &str, ) -> Result<Vec<u8>, WidgetManagerError>

Get a previously installed widget

Arguments
  • widget_name - The name of the widget to get
Returns

The compiled widget TODO: return Vec for now, could use CompiledWidget when runtime is ready

pub async fn get_widgets() -> Result<Vec<String>, WidgetManagerError>