pub struct EspHttpClient {
stack: Stack<'static>,
tls_seed: u64,
}Fields
stack: Stack<'static>tls_seed: u64Implementations
Sourceimpl EspHttpClient
impl EspHttpClient
Sourcepub fn new(stack: Stack<'static>, tls_seed: u64) -> Self
pub fn new(stack: Stack<'static>, tls_seed: u64) -> Self
Creates a new client from a network stack and TLS seed.
Sourcepub async fn request(
&self,
method: Method,
url: &str,
body: Option<&[u8]>,
) -> Result<Response, Error>
pub async fn request( &self, method: Method, url: &str, body: Option<&[u8]>, ) -> Result<Response, Error>
Sends an HTTP request to url, following up to 5 redirects automatically.
Errors
Returns [Error::Codec] if the redirect limit is exceeded or a redirect
response is missing the Location header.