pub struct Renderer {
widgets: Vec<WasmWidget>,
framebuffer: Box<[Rgb565; 76800]>,
background_color: Rgb565,
runtime: Runtime,
ip_address: String,
}Fields
widgets: Vec<WasmWidget>framebuffer: Box<[Rgb565; 76800]>background_color: Rgb565runtime: Runtimeip_address: StringImplementations
Sourceimpl Renderer
impl Renderer
pub fn new() -> Self
Sourcefn update_widget_information(&mut self, config: &SystemConfiguration)
fn update_widget_information(&mut self, config: &SystemConfiguration)
Update the information stored in Renderer::widgets based on the provided [SystemConfiguration].
Sourcepub async fn run(&mut self)
pub async fn run(&mut self)
Renderer loop, stores copy of [SystemConfiguration] and updates it only if changes are detected via Storage::get_system_config_change.
This function will never return and run indefinitly.
Runs on the seccond core due to Runtime::run() being blocking due to Wasmtime’s host functions.
See runtime::http_sync for details.
Only loads and runs widgets once their update cycle has passed.
Sourceasync fn update_widgets(&mut self)
async fn update_widgets(&mut self)
Checks if any widget needs to be run this cycle, runs them, and updates their last output.
Sourceasync fn render_layout(&mut self)
async fn render_layout(&mut self)
Renders the screen layout, writes into a framebuffer to avoid screen flickering.