pub struct Wifi {
stack: Stack<'static>,
tls_seed: u64,
}Expand description
Struct to hold relevenat states for other modules (http server/client)
Fields
stack: Stack<'static>tls_seed: u64Implementations
Sourceimpl Wifi
impl Wifi
Sourcepub fn start_station(
wifi_peripheral: WIFI<'static>,
spawner: &Spawner,
ssid: String,
password: String,
use_ap: bool,
) -> Self
pub fn start_station( wifi_peripheral: WIFI<'static>, spawner: &Spawner, ssid: String, password: String, use_ap: bool, ) -> Self
Initialises the WiFi radio.
With use_ap = false, the device will attempt to connect to the specified WiFi network as a station.
If it fails to connect after a number of attempts, it will switch to AP mode and reboot to allow the user to connect and configure WiFi credentials via UI.
Call wait_for_connection to wait until connection is fully established is in station mode.
Sourcepub fn stack(&self) -> Stack<'static>
pub fn stack(&self) -> Stack<'static>
Returns the embassy-net stack. Pass to EspHttpClient::new.
Sourcepub fn tls_seed(&self) -> u64
pub fn tls_seed(&self) -> u64
Returns the TLS seed. Pass to EspHttpClient::new.
Sourcepub async fn wait_for_connection(&self) -> Ipv4Cidr
pub async fn wait_for_connection(&self) -> Ipv4Cidr
Waits asynchronously until the WiFi link is up.